@@ -2,6 +2,7 @@
 # -*- coding: utf8 -*-
 
 from . import libswn as swn
+from .workday import *
 
 import datetime,time,inspect,collections,hashlib,base64,urllib.request,json,subprocess
 import os,re,shutil,smtplib,sys,getpass
@@ -623,42 +624,6 @@ class c_xx(object):   #消息处理
         消息内容=消息内容.replace("\n","<br>")
         self.cc.execute("select f_text_email('rtta@rtfund.com',:z,:bt,:xxnr,:ts) from dual",z=组,xxnr=消息内容,bt=标题,ts=消息保存天数)
 
-def lastday(rq,wtype='0'):  #取指定日期的上一工作日
-    lastd, xq, jg, i = (None, None, None, 0)
-    while i < 30:
-        lastd = datetime.datetime.strptime(rq, "%Y%m%d") - datetime.timedelta(days=1)
-        xq = lastd.weekday()
-        jg = swdb.jg1("select count(*) from tworkday where d_date='%s' and c_type='%s'" % (lastd.strftime('%Y%m%d'),wtype))
-        if (xq >= 5 and jg == 1):
-            break
-        if (xq < 5 and jg == 0):
-            break
-        rq = lastd.strftime('%Y%m%d')
-        i = i + 1
-    return lastd.strftime('%Y%m%d')
-    
-def nextday(rq,wtype='0'):  #取指定日期的下一工作日
-    nextd, xq, jg, i = (None, None, None, 0)
-    while i < 30:
-        nextd = datetime.datetime.strptime(rq, "%Y%m%d") + datetime.timedelta(days=1)
-        xq = nextd.weekday()
-        jg = swdb.jg1("select count(*) from tworkday where d_date='%s' and c_type='%s'" % (nextd.strftime('%Y%m%d'),wtype))
-        if (xq >= 5 and jg == 1):
-            break
-        if (xq < 5 and jg == 0):
-            break
-        rq = nextd.strftime('%Y%m%d')
-        i = i + 1
-    return nextd.strftime('%Y%m%d')
-
-def isworkday(rq,wtype='0'):    #判断是否工作日
-    xq=datetime.datetime.strptime(rq, "%Y%m%d").weekday()   #返回0-6,1是周一，6是周日
-    jg = swdb.jg1("select count(*) from tworkday where d_date='%s' and c_type='%s'" % (rq,wtype))
-    if xq<5:    #周一到周五
-        return jg==0
-    else:
-        return jg>0
-
 def swexit(returncode,msg="",nextchecktime=""): #事务退出环节
     global swrq
     if swid==0: #事务id为0是测试，不用写退出环节
@@ -719,6 +684,8 @@ swrq=swenv("swrq","")
 oraconn=swenv("oracle","")
 if oraconn!="":
     swdb.connect(oraconn)
+else:
+    swdb=None
 stime=time.time()
 srvname=swenv("srvname","")
 srvpass=swenv("srvpass","")
